@@ -41,3 +41,14 @@ def parse_orcid(text):
     if name and orcid:
         results.append((name, orcid))
     return results
+
+
+def parse_orcid_info(text, *, hmt=True):
+    results = parse_orcid(text)
+    infos = []
+    for name, orcid in results:
+        infos.append(dict(
+            name=name,
+            orcid=orcid,
+        ))
+    return infos
